@@ -8,8 +8,7 @@
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
+ * version 2.1 as published by the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -38,30 +37,18 @@
 #define USE_AF_DESKTOP_MAIN__
  
 #ifdef USE_AF_DESKTOP_MAIN__
+
+#include "maemo-af-desktop-main.h"
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
  
-/* GTK includes */ 
-#include <gtk/gtkmain.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtktogglebutton.h>
-
-/* status bar GTK includes */
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkfixed.h>
 /* home gtk includes */
-#include <gdk/gdkx.h>
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
+#include <gtk/gtkmain.h>
 #include <gtk/gtkwidget.h>
-
-
-#include <unistd.h>
-
-/* GDK includes */
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
-#include <gtk/gtk.h>
+#include <libgnomevfs/gnome-vfs.h>
 
 /* System includes */
 #include <string.h>
@@ -69,83 +56,41 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <stdlib.h>
-
-
-/* GDK includes */
-#include <gdk/gdkwindow.h>
-#include <gdk/gdkx.h>
-
-/* GLib include */
-#include <glib.h>
-
-/* X include */
-#include <X11/X.h>
-#include <X11/Xatom.h>
-#include <X11/Xlib.h>
-
-
-/* dlfcn include */
-#include <dlfcn.h>
-
-/* stdio include */
 #include <stdio.h>
-
-/* libintl include */
+#include <fcntl.h>  /* for fcntl, O_NONBLOCK */
+#include <signal.h> /* for signal */
 #include <libintl.h>
-
-/* Locale include */
 #include <locale.h>
+#include <libosso.h>
+/*#include <osso-log.h>*/
 
 /* Hildon includes */
 #include "hildon-navigator/osso-manager.h"
 #include "hildon-navigator/hildon-navigator.h"
-#include "hildon-navigator/application-switcher.h"
-#include "hildon-navigator/others-menu.h"
-
-
-/* Hildon status bar includes */
+#include "hildon-navigator/hildon-navigator-window.h"
+#include "hildon-navigator/hn-app-switcher.h"
 #include "hildon-status-bar/hildon-status-bar-lib.h"
 #include "hildon-status-bar/hildon-status-bar-item.h"
+#include "hildon-status-bar/hildon-status-bar-interface.h"
+#include "hildon-home/hildon-home-interface.h"
+
+/* Hildon status bar includes */
+#include <hildon-widgets/hildon-file-chooser-dialog.h>
+#include <hildon-widgets/hildon-defines.h>
 #include <hildon-widgets/gtk-infoprint.h>
 #include <hildon-widgets/hildon-note.h>
 
-
-#include <libosso.h>
-/*#include <osso-log.h>*/
-
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <locale.h>
-#include <libintl.h>
-#include <math.h>
-#include <stdio.h>
-#include <libmb/mbutil.h>
-
-#include <libgnomevfs/gnome-vfs.h>
-#include <fcntl.h>		/* for fcntl, O_NONBLOCK */
-#include <signal.h>		/* for signal */
-
-#include "libmb/mbdotdesktop.h"
-#include <hildon-widgets/hildon-note.h>
-#include <hildon-widgets/hildon-file-chooser-dialog.h>
-#include <hildon-widgets/hildon-defines.h>
+#include <hildon-base-lib/hildon-base-dnotify.h>
 
 /* log include */
 #include <log-functions.h>
 
 /* Header file */
-#include "maemo-af-desktop-main.h"
-#include "hildon-status-bar/hildon-status-bar-interface.h"
-#include "hildon-home/hildon-home-interface.h"
-#include "hildon-navigator/hildon-navigator-interface.h"
 #include "kstrace.h"
 /* Moved from main to globals to reduce the amount
    of used stack -- Karoliina Salminen */
 
-Navigator tasknav;
+HildonNavigatorWindow *tasknav;
 osso_context_t *osso;
 StatusBar *panel;
 
@@ -158,7 +103,8 @@ static gint keysnooper_id;
 /*
  * Signaling pipe handle
  */
-void pipe_signals(int signal)
+static void 
+pipe_signals(int signal)
 {
     if(write(signal_pipe[1], &signal, sizeof(int)) != sizeof(int))
     {
@@ -173,7 +119,8 @@ void pipe_signals(int signal)
  *   G_IO_IN or G_IO_PRI (I don't know what could lead to G_IO_PRI)
  * the pointer d is always NULL
  */
-gboolean deliver_signal(GIOChannel *source, GIOCondition cond, gpointer d)
+static gboolean 
+deliver_signal(GIOChannel *source, GIOCondition cond, gpointer d)
 {
     GError *error = NULL;		/* for error handling */
 
@@ -244,18 +191,26 @@ gboolean deliver_signal(GIOChannel *source, GIOCondition cond, gpointer d)
     return (TRUE);		/* keep the event source */
 }
 
-static gboolean initialize_navigator_menus_wrapper(gpointer data);
+gboolean hildon_home_window_applets_init_wrapper (gpointer data);
 
-static gboolean initialize_navigator_menus_wrapper(gpointer data) {
-    initialize_navigator_menus((Navigator *)data);
+static gboolean
+start_status_bar (void)
+{
+    status_bar_main(osso, &panel);
+
+    /* load home applets when status bar is done */
+    g_idle_add (&hildon_home_window_applets_init_wrapper, NULL);
+ 
     return FALSE;
 }
 
-int maemo_af_desktop_main(int argc, char* argv[])
+
+int 
+maemo_af_desktop_main(int argc, char* argv[])
 {
     GIOChannel *g_signal_in; 
 
-    GError *error = NULL;	/* handle errors */
+    GError *error = NULL;   /* handle errors */
     long fd_flags; 	    /* used to change the pipe into non-blocking mode */
     gchar *gtkrc = NULL;
 
@@ -290,7 +245,7 @@ int maemo_af_desktop_main(int argc, char* argv[])
 
     gnome_vfs_init();
 
-        /* initialize osso */
+    /* initialize osso */
     osso = osso_initialize( HILDON_STATUS_BAR_NAME, 
                             HILDON_STATUS_BAR_VERSION, FALSE, NULL );
     if( !osso )
@@ -300,12 +255,18 @@ int maemo_af_desktop_main(int argc, char* argv[])
     }
     
 
-    task_navigator_main(&tasknav);
+    /* Initialize hildon-base-lib (for dnotify) */
+    if (hildon_dnotify_handler_init () != HILDON_OK)
+      g_warning ("Could not initialize hildon-base-lib dnotify handler");
 
     keysnooper_id = 0;
     keysnooper_id=hildon_home_main();
 
-    status_bar_main(osso, &panel);
+    tasknav = hildon_navigator_window_new ();
+
+    gtk_widget_show_all (GTK_WIDGET (tasknav));
+
+    g_idle_add ((GSourceFunc)start_status_bar, NULL);
 
     if(pipe(signal_pipe)) 
     {
@@ -351,26 +312,21 @@ int maemo_af_desktop_main(int argc, char* argv[])
 
     /* register the reading end with the event loop */
     g_io_add_watch(g_signal_in, G_IO_IN | G_IO_PRI, deliver_signal, NULL);
-
-    /* set idle function to initialize navigator menus */
-    g_idle_add(&initialize_navigator_menus_wrapper, &tasknav);
-
+    
     gtk_main();
+    
     home_deinitialize(keysnooper_id);
     status_bar_deinitialize(osso,&panel);
-    task_navigator_deinitialize(&tasknav);
     
     osso_deinitialize( osso );
       
     return 0;
 }
     
-int main( int argc, char* argv[] )
+int 
+main( int argc, char* argv[] )
 {
-    
-    return maemo_af_desktop_main(argc,argv);   
-        
+   return maemo_af_desktop_main(argc,argv);        
 }
 
-
 #endif
